"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DayPicker = DayPicker;
const react_1 = __importDefault(require("react"));
const UI_js_1 = require("./UI.js");
const getClassNamesForModifiers_js_1 = require("./helpers/getClassNamesForModifiers.js");
const getComponents_js_1 = require("./helpers/getComponents.js");
const getDataAttributes_js_1 = require("./helpers/getDataAttributes.js");
const getDateLib_js_1 = require("./helpers/getDateLib.js");
const getDefaultClassNames_js_1 = require("./helpers/getDefaultClassNames.js");
const getDropdownMonths_js_1 = require("./helpers/getDropdownMonths.js");
const getDropdownYears_js_1 = require("./helpers/getDropdownYears.js");
const getFormatters_js_1 = require("./helpers/getFormatters.js");
const getStyleForModifiers_js_1 = require("./helpers/getStyleForModifiers.js");
const getWeekdays_js_1 = require("./helpers/getWeekdays.js");
const defaultLabels = __importStar(require("./labels/index.js"));
const useCalendar_js_1 = require("./useCalendar.js");
const useDayPicker_js_1 = require("./useDayPicker.js");
const useFocus_js_1 = require("./useFocus.js");
const useModifiers_js_1 = require("./useModifiers.js");
const useSelection_js_1 = require("./useSelection.js");
/**
 * Render the date picker calendar.
 *
 * @group DayPicker
 * @see http://daypicker.dev
 */
function DayPicker(props) {
    const reactId = react_1.default.useId();
    const id = props.id ?? reactId;
    const dateLib = (0, getDateLib_js_1.getDateLib)(props.dateLib);
    const components = (0, getComponents_js_1.getComponents)(props.components);
    const formatters = (0, getFormatters_js_1.getFormatters)(props.formatters);
    const labels = { ...defaultLabels, ...props.labels };
    const classNames = { ...(0, getDefaultClassNames_js_1.getDefaultClassNames)(), ...props.classNames };
    const numberOfMonths = props.numberOfMonths ?? 1;
    const calendar = (0, useCalendar_js_1.useCalendar)(props, dateLib);
    const modifiers = (0, useModifiers_js_1.useModifiers)(props, calendar, dateLib);
    const selection = (0, useSelection_js_1.useSelection)(props, dateLib);
    const focus = (0, useFocus_js_1.useFocus)(props, calendar, modifiers, selection, dateLib);
    const { captionLayout, dir, locale, ISOWeek, mode, modifiersClassNames, modifiersStyles, onDayBlur, onDayClick, onDayFocus, onDayKeyDown, onPrevClick, onNextClick, showWeekNumber, styles, weekStartsOn, firstWeekContainsDate, useAdditionalWeekYearTokens, useAdditionalDayOfYearTokens } = props;
    const { formatCaption, formatDay, formatMonthDropdown, formatWeekNumber, formatWeekNumberHeader, formatWeekdayName, formatYearDropdown } = formatters;
    const { labelDayButton, labelGridcell, labelGrid, labelMonthDropdown, labelNav, labelNext, labelPrevious, labelWeekday, labelWeekNumber, labelWeekNumberHeader, labelYearDropdown } = labels;
    const weekdays = (0, getWeekdays_js_1.getWeekdays)(locale, weekStartsOn, ISOWeek, dateLib);
    const isInteractive = mode !== undefined || onDayClick !== undefined;
    const handlePreviousClick = () => {
        if (!calendar.previousMonth)
            return;
        calendar.goToPreviousMonth();
        onPrevClick?.(calendar.previousMonth);
    };
    const handleNextClick = () => {
        if (!calendar.nextMonth)
            return;
        calendar.goToNextMonth();
        onNextClick?.(calendar.nextMonth);
    };
    const handleDayClick = (day, m) => {
        return (e) => {
            e.preventDefault();
            e.stopPropagation();
            selection?.handleSelect(day.date, m, e);
            focus.setFocused(day);
            onDayClick?.(day.date, m, e);
        };
    };
    const handleDayFocus = (day, m) => {
        return (e) => {
            focus.setFocused(day);
            onDayFocus?.(day.date, m, e);
        };
    };
    const handleDayBlur = (day, m) => {
        return (e) => {
            focus.blur();
            onDayBlur?.(day.date, m, e);
        };
    };
    const handleDayKeyDown = (day, m) => {
        return (e) => {
            switch (e.key) {
                case "ArrowLeft":
                    e.preventDefault();
                    e.stopPropagation();
                    dir === "rtl" ? focus.focusDayAfter() : focus.focusDayBefore();
                    break;
                case "ArrowRight":
                    e.preventDefault();
                    e.stopPropagation();
                    dir === "rtl" ? focus.focusDayBefore() : focus.focusDayAfter();
                    break;
                case "ArrowDown":
                    e.preventDefault();
                    e.stopPropagation();
                    focus.focusWeekAfter();
                    break;
                case "ArrowUp":
                    e.preventDefault();
                    e.stopPropagation();
                    focus.focusWeekBefore();
                    break;
                case " ":
                case "Enter":
                    e.preventDefault();
                    e.stopPropagation();
                    selection?.handleSelect(day.date, m, e);
                    break;
                case "PageUp":
                    e.preventDefault();
                    e.stopPropagation();
                    e.shiftKey ? focus.focusYearBefore() : focus.focusMonthBefore();
                    break;
                case "PageDown":
                    e.preventDefault();
                    e.stopPropagation();
                    e.shiftKey ? focus.focusYearAfter() : focus.focusMonthAfter();
                    break;
                case "Home":
                    e.preventDefault();
                    e.stopPropagation();
                    focus.focusStartOfWeek();
                    break;
                case "End":
                    e.preventDefault();
                    e.stopPropagation();
                    focus.focusEndOfWeek();
                    break;
            }
            onDayKeyDown?.(day.date, m, e);
        };
    };
    const formatOptions = {
        locale,
        weekStartsOn,
        firstWeekContainsDate,
        useAdditionalWeekYearTokens,
        useAdditionalDayOfYearTokens
    };
    const labelOptions = formatOptions;
    return (react_1.default.createElement(useDayPicker_js_1.dayPickerContext.Provider, { value: { ...calendar, ...selection, ...modifiers } },
        react_1.default.createElement("div", { className: [classNames[UI_js_1.UI.Root], props.className]
                .filter(Boolean)
                .join(" "), style: { ...styles?.[UI_js_1.UI.Root], ...props.style }, dir: props.dir, id: props.id, lang: props.lang, nonce: props.nonce, title: props.title, "data-interactive": isInteractive || undefined, "data-multiple-months": numberOfMonths > 1 || undefined, "data-week-numbers": showWeekNumber || undefined, ...(0, getDataAttributes_js_1.getDataAttributes)(props) },
            react_1.default.createElement(components.Months, { className: classNames[UI_js_1.UI.Months], style: styles?.[UI_js_1.UI.Months] },
                !props.hideNavigation && (react_1.default.createElement(components.Nav, { role: "toolbar", className: classNames[UI_js_1.UI.Nav], style: styles?.[UI_js_1.UI.Nav], "aria-label": labelNav() },
                    react_1.default.createElement(components.Button, { type: "button", className: classNames[UI_js_1.UI.ButtonPrevious], tabIndex: calendar.previousMonth ? undefined : -1, disabled: calendar.previousMonth ? undefined : true, "aria-label": labelPrevious(calendar.previousMonth, {
                            locale
                        }), "aria-controls": id, onClick: handlePreviousClick },
                        react_1.default.createElement(components.Chevron, { disabled: calendar.previousMonth ? undefined : true, className: classNames[UI_js_1.UI.Chevron], orientation: "left" })),
                    react_1.default.createElement(components.Button, { type: "button", className: classNames[UI_js_1.UI.ButtonNext], tabIndex: calendar.nextMonth ? undefined : -1, disabled: calendar.nextMonth ? undefined : true, "aria-label": labelNext(calendar.nextMonth, labelOptions), "aria-controls": id, onClick: handleNextClick },
                        react_1.default.createElement(components.Chevron, { disabled: calendar.previousMonth ? undefined : true, orientation: "right", className: classNames[UI_js_1.UI.Chevron] })))),
                calendar.months.map((calendarMonth, displayIndex) => {
                    const captionId = `${id}-caption-${displayIndex}`;
                    const handleMonthChange = (e) => {
                        const selectedMonth = Number(e.target.value);
                        const month = dateLib.setMonth(dateLib.startOfMonth(calendarMonth.date), selectedMonth);
                        calendar.goToMonth(month);
                    };
                    const handleYearChange = (e) => {
                        const month = dateLib.setYear(dateLib.startOfMonth(calendarMonth.date), Number(e.target.value));
                        calendar.goToMonth(month);
                    };
                    const dropdownMonths = (0, getDropdownMonths_js_1.getDropdownMonths)(calendarMonth.date, calendar.navigationStartMonth, calendar.navigationEndMonth, formatters, locale, dateLib);
                    const dropdownYears = (0, getDropdownYears_js_1.getDropdownYears)(calendar.months[0].date, calendar.navigationStartMonth, calendar.navigationEndMonth, formatters, dateLib);
                    return (react_1.default.createElement(components.Month, { className: classNames[UI_js_1.UI.Month], style: styles?.[UI_js_1.UI.Month], key: displayIndex, displayIndex: displayIndex, calendarMonth: calendarMonth },
                        react_1.default.createElement(components.MonthCaption, { className: classNames[UI_js_1.UI.MonthCaption], style: styles?.[UI_js_1.UI.MonthCaption], id: captionId, calendarMonth: calendarMonth, displayIndex: displayIndex }, captionLayout?.startsWith("dropdown") ? (react_1.default.createElement(components.DropdownNav, { className: classNames[UI_js_1.UI.DropdownNav], style: styles?.[UI_js_1.UI.DropdownNav] },
                            captionLayout === "dropdown" ||
                                captionLayout === "dropdown-months" ? (react_1.default.createElement(components.Dropdown, { "aria-label": labelMonthDropdown(), classNames: classNames, components: components, disabled: Boolean(props.disableNavigation), onChange: handleMonthChange, options: dropdownMonths, style: styles?.[UI_js_1.UI.Dropdown], value: calendarMonth.date.getMonth() })) : (react_1.default.createElement("span", { role: "status", "aria-live": "polite" }, formatMonthDropdown(calendarMonth.date.getMonth()))),
                            captionLayout === "dropdown" ||
                                captionLayout === "dropdown-years" ? (react_1.default.createElement(components.Dropdown, { "aria-label": labelYearDropdown(labelOptions), classNames: classNames, components: components, disabled: Boolean(props.disableNavigation), onChange: handleYearChange, options: dropdownYears, style: styles?.[UI_js_1.UI.Dropdown], value: calendarMonth.date.getFullYear() })) : (react_1.default.createElement("span", { role: "status", "aria-live": "polite" }, formatYearDropdown(calendarMonth.date.getFullYear()))))) : (react_1.default.createElement(components.CaptionLabel, { className: classNames[UI_js_1.UI.CaptionLabel], role: "status", "aria-live": "polite" }, formatCaption(calendarMonth.date, formatOptions, dateLib)))),
                        react_1.default.createElement(components.MonthGrid, { role: "grid", "aria-multiselectable": mode === "multiple" || mode === "range", "aria-label": labelGrid(calendarMonth.date, labelOptions, dateLib) ||
                                undefined, className: classNames[UI_js_1.UI.MonthGrid], style: styles?.[UI_js_1.UI.MonthGrid] },
                            react_1.default.createElement(components.Weekdays, { className: classNames[UI_js_1.UI.Weekdays], hidden: props.hideWeekdayRow, role: "row", style: styles?.[UI_js_1.UI.Weekdays] },
                                showWeekNumber && (react_1.default.createElement(components.WeekNumberHeader, { "aria-label": labelWeekNumberHeader(labelOptions), className: classNames[UI_js_1.UI.WeekNumberHeader], role: "columnheader", style: styles?.[UI_js_1.UI.WeekNumberHeader] }, !props.hideWeekdayRow && formatWeekNumberHeader())),
                                weekdays.map((weekday, i) => (react_1.default.createElement(components.Weekday, { "aria-label": labelWeekday(weekday, labelOptions, dateLib), className: classNames[UI_js_1.UI.Weekday], key: i, role: "columnheader", style: styles?.[UI_js_1.UI.Weekday] }, formatWeekdayName(weekday, formatOptions, dateLib))))),
                            react_1.default.createElement(components.Weeks, { className: classNames[UI_js_1.UI.Weeks], role: "rowgroup", style: styles?.[UI_js_1.UI.Weeks] }, calendarMonth.weeks.map((week, weekIndex) => {
                                return (react_1.default.createElement(components.Week, { className: classNames[UI_js_1.UI.Week], key: week.weekNumber, role: "row", style: styles?.[UI_js_1.UI.Week], week: week },
                                    showWeekNumber && (react_1.default.createElement(components.WeekNumber, { week: week, role: "rowheader", style: styles?.[UI_js_1.UI.WeekNumber], "aria-label": labelWeekNumber(week.weekNumber, {
                                            locale
                                        }), className: classNames[UI_js_1.UI.WeekNumber] }, formatWeekNumber(week.weekNumber))),
                                    week.days.map((day, dayIndex) => {
                                        const m = modifiers.getModifiers(day);
                                        if (!m.disabled) {
                                            if (selection?.isSelected(day.date) &&
                                                !m.disabled) {
                                                m[UI_js_1.SelectionState.selected] = true;
                                            }
                                            if (mode === "range") {
                                                const { isRangeEnd, isRangeStart, isRangeMiddle } = selection;
                                                if (isRangeStart(day.date)) {
                                                    m[UI_js_1.SelectionState.range_start] = true;
                                                }
                                                if (isRangeMiddle(day.date)) {
                                                    m[UI_js_1.SelectionState.range_middle] = true;
                                                }
                                                if (isRangeEnd(day.date)) {
                                                    m[UI_js_1.SelectionState.range_end] = true;
                                                }
                                            }
                                        }
                                        const isFocused = Boolean(focus.focused?.isEqualTo(day));
                                        const style = {
                                            ...(0, getStyleForModifiers_js_1.getStyleForModifiers)(m, modifiersStyles),
                                            ...styles?.[UI_js_1.UI.Day]
                                        };
                                        const className = [
                                            classNames[UI_js_1.UI.Day],
                                            ...(0, getClassNamesForModifiers_js_1.getClassNamesForModifiers)(m, classNames, modifiersClassNames),
                                            ...(isFocused
                                                ? [classNames[UI_js_1.DayFlag.focused]]
                                                : [])
                                        ];
                                        return (react_1.default.createElement(components.Day, { key: `${dateLib.format(day.date, "yyyy-MM-dd")}_${dateLib.format(day.displayMonth, "yyyy-MM")}`, day: day, modifiers: m, role: "gridcell", className: className.join(" "), style: style, "aria-hidden": m.hidden || undefined, "aria-selected": m.selected || undefined, "aria-label": !isInteractive
                                                ? labelGridcell(day.date, m, labelOptions, dateLib)
                                                : undefined, "data-day": dateLib.format(day.date, "yyyy-MM-dd"), "data-month": numberOfMonths > 1
                                                ? dateLib.format(day.date, "yyyy-MM")
                                                : undefined, "data-selected": m.selected || undefined, "data-disabled": m.disabled || undefined, "data-hidden": m.hidden || undefined, "data-focused": isFocused || undefined }, isInteractive ? (react_1.default.createElement(components.DayButton, { className: classNames[UI_js_1.UI.DayButton], style: styles?.[UI_js_1.UI.DayButton], day: day, modifiers: m, focused: isFocused, disabled: m.disabled || undefined, tabIndex: focus.isFocusTarget(day) ? 0 : -1, "aria-label": labelDayButton(day.date, m, labelOptions, dateLib), onClick: handleDayClick(day, m), onBlur: handleDayBlur(day, m), onFocus: handleDayFocus(day, m), onKeyDown: handleDayKeyDown(day, m) }, formatDay(day.date, formatOptions, dateLib))) : (formatDay(day.date, formatOptions, dateLib))));
                                    })));
                            })))));
                })),
            props.footer && (react_1.default.createElement(components.Footer, { className: classNames[UI_js_1.UI.Footer], style: styles?.[UI_js_1.UI.Footer], role: "status", "aria-live": "polite" }, props.footer)))));
}
//# sourceMappingURL=DayPicker.js.map